# Body Manage
[![pypi version](https://img.shields.io/pypi/v/body_manage.svg)](https://pypi.org/project/body_manage) ![MIT License](https://img.shields.io/pypi/l/body_manage.svg)

Body 2.0 service that handles updating and controlling services and portals
remotely.

Please see [LICENSE](https://github.com/ouroboroscoding/body-manage/blob/main/LICENSE) for further information.

# Documentation

[RESTful](https://github.com/ouroboroscoding/body-manage/blob/main/rest.md)